==> epiphany-1.5.2.tar.gz: epiphany-1.5.2/src/ephy-notebook.h <==
/*
 *  Copyright (C) 2002 Christophe Fergeau
 *  Copyright (C) 2003 Marco Pesenti Gritti
 *  Copyright (C) 2003, 2004 Christian Persch
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: ephy-notebook.h,v 1.11 2004/10/25 13:43:02 chpe Exp $
 */

#ifndef EPHY_NOTEBOOK_H
#define EPHY_NOTEBOOK_H

#include "ephy-tab.h"

#include <glib.h>
#include <gtk/gtknotebook.h>

G_BEGIN_DECLS

#define EPHY_TYPE_NOTEBOOK		(ephy_notebook_get_type ())
#define EPHY_NOTEBOOK(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_NOTEBOOK, EphyNotebook))
#define EPHY_NOTEBOOK_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_NOTEBOOK, EphyNotebookClass))
#define EPHY_IS_NOTEBOOK(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_NOTEBOOK))
#define EPHY_IS_NOTEBOOK_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_NOTEBOOK))
#define EPHY_NOTEBOOK_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_NOTEBOOK, EphyNotebookClass))

typedef struct EphyNotebookClass	EphyNotebookClass;
typedef struct EphyNotebook		EphyNotebook;
typedef struct EphyNotebookPrivate	EphyNotebookPrivate;

struct EphyNotebook
{
	GtkNotebook parent;

	/*< private >*/
        EphyNotebookPrivate *priv;
};

struct EphyNotebookClass
{
        GtkNotebookClass parent_class;

	/* Signals */
	void	 (* tab_added)      (EphyNotebook *notebook,
				     EphyTab *tab);
	void	 (* tab_removed)    (EphyNotebook *notebook,
				     EphyTab *tab);
	void	 (* tab_detached)   (EphyNotebook *notebook,
				     EphyTab *tab);
	void	 (* tabs_reordered) (EphyNotebook *notebook);
	gboolean (* tab_delete)	    (EphyNotebook *notebook,
				     EphyTab *tab);
};

GType		ephy_notebook_get_type		(void);

GtkWidget      *ephy_notebook_new		(void);

void		ephy_notebook_add_tab		(EphyNotebook *nb,
						 EphyTab *tab,
						 int position,
						 gboolean jump_to);

void		ephy_notebook_remove_tab	(EphyNotebook *nb,
						 EphyTab *tab);

void            ephy_notebook_move_tab		(EphyNotebook *src,
						 EphyNotebook *dest,
						 EphyTab *tab,
						 int dest_position);

void		ephy_notebook_set_show_tabs	(EphyNotebook *nb,
						 gboolean show_tabs);

G_END_DECLS

#endif /* EPHY_NOTEBOOK_H */

==> epiphany-1.8.0.tar.gz: epiphany-1.8.0/src/ephy-notebook.h <==
/*
 *  Copyright (C) 2002 Christophe Fergeau
 *  Copyright (C) 2003 Marco Pesenti Gritti
 *  Copyright (C) 2003, 2004 Christian Persch
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: ephy-notebook.h,v 1.13 2005/04/17 19:38:59 chpe Exp $
 */

#ifndef EPHY_NOTEBOOK_H
#define EPHY_NOTEBOOK_H

#include "ephy-tab.h"

#include <glib.h>
#include <gtk/gtknotebook.h>

G_BEGIN_DECLS

#define EPHY_TYPE_NOTEBOOK		(ephy_notebook_get_type ())
#define EPHY_NOTEBOOK(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_NOTEBOOK, EphyNotebook))
#define EPHY_NOTEBOOK_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_NOTEBOOK, EphyNotebookClass))
#define EPHY_IS_NOTEBOOK(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_NOTEBOOK))
#define EPHY_IS_NOTEBOOK_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_NOTEBOOK))
#define EPHY_NOTEBOOK_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_NOTEBOOK, EphyNotebookClass))

typedef struct _EphyNotebookClass	EphyNotebookClass;
typedef struct _EphyNotebook		EphyNotebook;
typedef struct _EphyNotebookPrivate	EphyNotebookPrivate;

struct _EphyNotebook
{
	GtkNotebook parent;

	/*< private >*/
        EphyNotebookPrivate *priv;
};

struct _EphyNotebookClass
{
        GtkNotebookClass parent_class;

	/* Signals */
	void	 (* tab_added)      (EphyNotebook *notebook,
				     EphyTab *tab);
	void	 (* tab_removed)    (EphyNotebook *notebook,
				     EphyTab *tab);
	void	 (* tab_detached)   (EphyNotebook *notebook,
				     EphyTab *tab);
	void	 (* tabs_reordered) (EphyNotebook *notebook);
	gboolean (* tab_delete)	    (EphyNotebook *notebook,
				     EphyTab *tab);
};

GType		ephy_notebook_get_type		(void);

GtkWidget      *ephy_notebook_new		(void);

void		ephy_notebook_add_tab		(EphyNotebook *nb,
						 EphyTab *tab,
						 int position,
						 gboolean jump_to);

void		ephy_notebook_remove_tab	(EphyNotebook *nb,
						 EphyTab *tab);

void            ephy_notebook_move_tab		(EphyNotebook *src,
						 EphyNotebook *dest,
						 EphyTab *tab,
						 int dest_position);

void		ephy_notebook_set_show_tabs	(EphyNotebook *nb,
						 gboolean show_tabs);

void		ephy_notebook_set_dnd_enabled	(EphyNotebook *nb,
						 gboolean enabled);

G_END_DECLS

#endif /* EPHY_NOTEBOOK_H */
